DTimerCountdown class

倒计时

Constructors

DTimerCountdown({int interval = Duration.millisecondsPerSecond, int totalTime = 0})
初始化

Properties

hashCode int
The hash code for this object.
no setterinherited
isActive bool
Timer是否启动.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel() → void
取消计时器.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setDuration(int interval) → void
设置Timer间隔
setDurationFromSecond(int interval) → void
设置Timer间隔
setOnTimerCountdownCallback(void callback(int)) → void
setTotalTime(int totalTime) → void
设置倒计时
setTotalTimeWithSecond(int totalTime) → void
设置倒计时
startCountDown() → void
启动倒计时Timer.
stop() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited